@@ -1,4 +1,3 @@
-
 "scree.plot" <-
 function(namefile, title="Scree Plot", type="R", use="complete.obs", simu="F")
 {
@@ -11,8 +10,9 @@ if (type=="V") eigenval <- eigen(cov(mat,use="pairwise.complete.obs"), symmetric
 if (type=="E") eigenval <- namefile
 if (type=="M") eigenval <- eigen(namefile, symmetric=TRUE)$values
 
-
-plot(eigenval, type = "b", pch = 16, bty = "n", main = title, xlab = "", ylab = "")	
+nev <- length(eigenval)
+plot(eigenval, type = "b", pch = 16, bty = "o", main = title, xlab = "Dimension", ylab = "Eigenvalue")
+lines(c(1,nev),c(1,1),lty=2)	
 
 if (is.numeric(simu) && (type=="R"))
 {
